==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/HyperVReplicaAzureDiskInputDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Disk input details.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM ID.
 * @property diskId The DiskId.
 * @property diskType The DiskType.
 * @property logStorageAccountId The LogStorageAccountId.
 */
public data class HyperVReplicaAzureDiskInputDetailsArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val logStorageAccountId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVReplicaAzureDiskInputDetailsArgs].
 */
@PulumiTagMarker
public class HyperVReplicaAzureDiskInputDetailsArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("intwjkgybonpwhpy")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("qckknxtpllgitwfe")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("xofyykqtueafwhsx")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("ybirjaybjfdlbssr")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("wejhjoptfomwddpb")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("aqlwqyhcselyusng")
    public suspend fun diskId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("krlolobbgysakxbg")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("wdpumgwjlqbxsmwe")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("kxdaivuivtqwqsvx")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("pmjjahfrscshdjbi")
    public suspend fun logStorageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): HyperVReplicaAzureDiskInputDetailsArgs =
        HyperVReplicaAzureDiskInputDetailsArgs(
            diskEncryptionSetId = diskEncryptionSetId,
            diskId = diskId,
            diskType = diskType,
            logStorageAccountId = logStorageAccountId,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/HyperVReplicaAzureDiskInputDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Disk input details.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM ID.
 * @property diskId The DiskId.
 * @property diskType The DiskType.
 * @property logStorageAccountId The LogStorageAccountId.
 */
public data class HyperVReplicaAzureDiskInputDetailsArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>? = null,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val logStorageAccountId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.HyperVReplicaAzureDiskInputDetailsArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .logStorageAccountId(logStorageAccountId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVReplicaAzureDiskInputDetailsArgs].
 */
@PulumiTagMarker
public class HyperVReplicaAzureDiskInputDetailsArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var logStorageAccountId: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("vwtfpkjfctcyanmk")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("ysbhqunarqubuomx")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("ampfcnuqqusbqdtu")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("qhiyegdchfsmgoqc")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The DiskEncryptionSet ARM ID.
     */
    @JvmName("lxspsjydblanxwyg")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The DiskId.
     */
    @JvmName("fuyinjncfwttbulr")
    public suspend fun diskId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("unttpbnvuvjjkeau")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("yowitmnnmdincvub")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The DiskType.
     */
    @JvmName("srxuiefugsenusdm")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The LogStorageAccountId.
     */
    @JvmName("nmawoycnijsugrrg")
    public suspend fun logStorageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    internal fun build(): HyperVReplicaAzureDiskInputDetailsArgs =
        HyperVReplicaAzureDiskInputDetailsArgs(
            diskEncryptionSetId = diskEncryptionSetId,
            diskId = diskId,
            diskType = diskType,
            logStorageAccountId = logStorageAccountId,
        )
}
